@@ -1,12 +1,11 @@
 #include "Benchmark.h"
-#include <tagcoll/Exception.h>
+#include <wibble/exception.h>
 
 #include <stdarg.h>
 #include <time.h>
 #include <iostream>
 
 using namespace std;
-using namespace Tagcoll;
 
 Timer::~Timer()
 {
@@ -54,7 +53,7 @@ void Benchmark::run(const std::string& path)
 			if ((*i)->name() == child)
 				return (*i)->run(nextpath);
 	}
-	throw NotFoundException("looking for child " + path + " at " + fullName());
+	throw wibble::exception::Consistency("looking for benchmark " + path + " at " + fullName(), "benchmark not found");
 }
 
 // Run all subtests and this test
