@@ -107,7 +107,7 @@ public:
 			typename std::set<TAG> implying = coll.getTagsImplying(*t);
 			for (typename std::set<TAG>::const_iterator i = implying.begin();
 					i != implying.end(); ++i)
-				insert(wibble::singleton(*i), wibble::singleton(*t));
+				this->insert(wibble::singleton(*i), wibble::singleton(*t));
 		}
 	}
 
