@@ -24,6 +24,9 @@
 #include <tagcoll/stream/sink.h>
 #include <tagcoll/patch.h>
 #include <cstring>
+#ifndef HAVE_FMEMOPEN
+#include "tagcoll/tagexpr/fmemopen.h"
+#endif
 
 namespace tut {
 using namespace std;
