@@ -26,6 +26,9 @@
 #include <wibble/exception.h>
 #include <stdio.h>
 #include <errno.h>
+#ifndef HAVE_FMEMOPEN
+#include "tagcoll/tagexpr/fmemopen.h"
+#endif
 
 // using namespace std;
 using namespace wibble;
