@@ -1,7 +1,7 @@
 /*
  * tagged collection - Experimental programs to test and study tagged collections
  *
- * Copyright (C) 2003,2004,2005,2006  Enrico Zini
+ * Copyright (C) 2003--2008  Enrico Zini <enrico@enricozini.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,7 +90,8 @@ void printNode(HierarchyNode<COLL>* node, string prefix = "")
 	if (!items.empty())
 	{
 		printItems(items, prefix + ": ");
-//	} else {
+	} else {
+		cout << prefix << endl;
 //		printf("%.*s: no items\n", PFSTR(prefix));
 	}
 	
@@ -404,8 +405,8 @@ class Tagcoll
 
 	FilterStep* makeReaderHead(FilterStep* out)
 	{
-		if (opts.in_patch->boolValue())
-			if (opts.in_rename->boolValue())
+		if (opts.in_patch->isSet())
+			if (opts.in_rename->isSet())
 				return filterStep(
 						stream::patcher(patches,
 							stream::substitute(substitutions,
@@ -415,7 +416,7 @@ class Tagcoll
 						stream::patcher(patches,
 							FilterForwarder(out)));
 		else
-			if (opts.in_rename->boolValue())
+			if (opts.in_rename->isSet())
 				return filterStep(
 							stream::substitute(substitutions,
 								FilterForwarder(out)));
@@ -425,8 +426,8 @@ class Tagcoll
 
 	FilterStep* makeReaderMain(FilterStep* out)
 	{
-		bool hasImpl = opts.in_extimpl->boolValue();
-		bool hasDerv = opts.in_derived->boolValue();
+		bool hasImpl = opts.in_extimpl->isSet();
+		bool hasDerv = opts.in_derived->isSet();
 
 		if (hasImpl)
 			if (hasDerv)
@@ -527,17 +528,17 @@ public:
 	Tagcoll(wibble::commandline::TagcollParser& opts)
 		: opts(opts), m_writer(0)
 	{
-		if (opts.in_extimpl->boolValue())
+		if (opts.in_extimpl->isSet())
 		{
 			readCollection(opts.in_extimpl->stringValue(), inserter(implications));
 			// Pack the structure for faster expansions
 			implications.pack();
 		}
-		if (opts.in_derived->boolValue())
+		if (opts.in_derived->isSet())
 			readDerivedTags(opts.in_derived->stringValue(), derivedTags);
-		if (opts.in_rename->boolValue())
+		if (opts.in_rename->isSet())
 			readCollection(opts.in_rename->stringValue(), substitutions.inserter());
-		if (opts.in_patch->boolValue())
+		if (opts.in_patch->isSet())
 			patches = readPatches(opts.in_patch->stringValue());
 	}
 	~Tagcoll()
@@ -668,6 +669,23 @@ int main(int argc, const char* argv[])
 				cleanSmartHierarchyNode("_top", coll, flattenThreshold);
 			printNode(root, "/");
 		}
+		else if (opts.foundCommand() == opts.dischierarchy)
+		{
+			int flattenThreshold = 0;
+			if (opts.hie_flatten->boolValue())
+				flattenThreshold = opts.hie_flatten->intValue();
+
+			coll::Fast<string, string> coll;
+			tagcoll.readAll(inserter(coll));
+
+			if (opts.hie_filter->boolValue())
+				coll.removeTagsWithCardinalityLessThan(opts.hie_filter->intValue());
+
+			// Default operation: build the smart hierarchy
+			HierarchyNode< coll::Fast<string, string> >* root =
+				discHierarchyNode("_top", coll, flattenThreshold);
+			printNode(root, "/");
+		}
 		else if (opts.foundCommand() == opts.diff)
 		{
 			coll::Simple<string, string> merger1;
